@@ -15,3 +15,13 @@ from prosuite.parameter import Parameter
 from prosuite.dataset import BaseDataset
 from prosuite.factories.enums import *
 
+class Transformers:
+    @classmethod
+    def not_yet_implemented(cls, feature_class: BaseDataset, tolerance: float) -> Transformer:
+        """
+        Stay tuned
+        """
+        
+        result = Transformer("dummy(0)")
+        return result
+
